# ourskyai-sda-api
The basic flow for a new organization is as follows:
1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/GET/v1/satellite-targets) endpoint. Copy the id of the target you want to observe.
2. Create an organization target with the [organization target](#tag/organization-targets/GET/v1/organization-targets) endpoint. Use the id copied from above.
3. Create a webhook with the [webhook](#tag/webhooks/POST/v1/communications/webhook) endpoint to receive OSRs automatically (preferred) or use the [OSRs](#tag/observation-sequence-results/GET/v1/observation-sequence-results) endpoint to poll for OSRs.

Check out our [examples](https://github.com/ourskyai/oursky-examples) repository to see usage in each language.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.3.9821
- Package version: 1.3.9821
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

```sh
pip install ourskyai_sda_api
```
(you may need to run `pip` with root permission: `sudo pip install ourskyai_sda_api`)

### Poetry install
If you manage dependencies with [poetry](https://python-poetry.org/) then you can add the SDK with:

```sh
poetry add ourskyai_sda_api
```

### Import the package

Then import the package:
```python
import ourskyai_sda_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import os
import ourskyai_sda_api
from ourskyai_sda_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.prod.oursky.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = ourskyai_sda_api.Configuration(
    host = "https://api.prod.oursky.ai"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: BearerToken
configuration = ourskyai_sda_api.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with ourskyai_sda_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ourskyai_sda_api.DefaultApi(api_client)
    after = '2013-10-20T19:20:30+01:00' # datetime | The timestamp to get the next page of results. Defaults to the 1 day prior to the current UTC time. (optional)

    try:
        # Get uncorrelated tracks collected by the network.
        api_response = api_instance.get_uncorrelated_tracks(after=after)
        print("The response of DefaultApi->get_uncorrelated_tracks:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->get_uncorrelated_tracks: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.prod.oursky.ai/docs/sda*

<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerToken"></a>
### BearerToken

- **Type**: Bearer authentication

<a id="Roles"></a>
### Roles



## Author


